@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: data-default
-version: 0.5.3
-id: data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
-key: datad_DLQPsKM7BNMFfKH45X8LEe
+version: 0.6.0
+id: data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
+key: datad_91kEyGAjWztHB49awyDOYC
 license: BSD3
 maintainer: <l.mai@web.de>
 synopsis: A class for types with a default value
@@ -13,14 +13,14 @@ exposed: True
 exposed-modules:
     Data.Default
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/data-default-0.5.3
-library-dirs: /usr/lib/ghc-7.10.3/site-local/data-default-0.5.3
-data-dir: /usr/share/arm-linux-ghc-7.10.3/data-default-0.5.3
-hs-libraries: HSdata-default-0.5.3-DLQPsKM7BNMFfKH45X8LEe
+import-dirs: /usr/lib/ghc-7.10.3/site-local/data-default-0.6.0
+library-dirs: /usr/lib/ghc-7.10.3/site-local/data-default-0.6.0
+data-dir: /usr/share/arm-linux-ghc-7.10.3/data-default-0.6.0
+hs-libraries: HSdata-default-0.6.0-91kEyGAjWztHB49awyDOYC
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
-    data-default-instances-base-0.0.1-dbfd55503c26f723fa3c50252b90711b
+    data-default-instances-base-0.1.0-198bff61242257f5772aacd6c941b1bb
     data-default-instances-containers-0.0.1-ed6168e11a6fc6102a5f701a3cea56bd
     data-default-instances-dlist-0.0.1-07c76bc7fb831013858af27db0a47b68
     data-default-instances-old-locale-0.0.1-5d97b238ba08c1d784e8204bcf29d27f
